# 文件系统

## 数据结构

### 1.文件信息表（dt_file_info）

| 字段          | 字段说明       | 数据类型     | 备注                          |
| ------------- | -------------- | ------------ | ----------------------------- |
| id            | 主键           | varchar(40)  | 32位UUID                      |
| group_code    | 集团编码       | varchar(40)  |                               |
| file_name     | 文件名称       | varchar(50)  |                               |
| file_type     | 文件类型       | varchar(2)   | 0-文件，1-目录                |
| file_bucket   | 文件分组       | varchar(40)  | 默认为应用名                  |
| file_path     | 文件路径       | varchar(200) | 含文件名称 - 对应文件存储路径 |
| file_size     | 文件大小       | varchar(40)  |                               |
| business_id   | 关联业务Id     | varchar(50)  |                               |
| expire_date   | 保留期限       | char(14)     | 格式为yyyyMMddHHmmss          |
| creator       | 创建人账号id   | varchar(32)  |                               |
| creation_time | 创建时间       | char(14)     | 格式为yyyyMMddHHmmss          |
| modified_time | 最后更新时间   | char(14)     | 格式为yyyyMMddHHmmss          |
| modifier      | 最后更新账号id | varchar(32)  |                               |
| valid         | 合法标识       | tinyint(4)   | 0-无效,1-有效                 |
| ts            | 乐观锁         | timestamp    |                               |

## DDL语句

### 文件信息表

```sql
CREATE TABLE IF NOT EXISTS `dt_file_info` (
  `id` varchar(40) COLLATE utf8_bin NOT NULL COMMENT '主键',
  `group_code` varchar(40) COLLATE utf8_bin NOT NULL COMMENT '集团编码',
  `file_name` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT '文件名称',
  `file_type` varchar(2) COLLATE utf8_bin DEFAULT NULL COMMENT '0-文件，1-目录',
  `file_bucket` varchar(40) COLLATE utf8_bin DEFAULT NULL COMMENT '文件分组',
  `file_path` varchar(200) COLLATE utf8_bin DEFAULT NULL COMMENT '含文件名称 - 对应文件存储路径',
  `file_size` bigint(20) DEFAULT NULL COMMENT '文件大小',
  `business_id` varchar(50) COLLATE utf8_bin DEFAULT NULL COMMENT '关联业务Id',
  `expire_date` char(14) COLLATE utf8_bin DEFAULT NULL COMMENT '保留期限,格式为yyyyMMddHHmmss',
  `creator` varchar(32) COLLATE utf8_bin DEFAULT NULL COMMENT '创建人id',
  `creation_time` char(14) COLLATE utf8_bin DEFAULT NULL COMMENT '创建时间,格式为yyyyMMddHHmmss',
  `modified_time` char(14) COLLATE utf8_bin DEFAULT NULL COMMENT '最后更新时间,格式为yyyyMMddHHmmss',
  `modifier` varchar(32) COLLATE utf8_bin DEFAULT NULL COMMENT '最后更新账号id',
  `valid` tinyint(4) DEFAULT NULL COMMENT '合法标识,0-无效,1-有效',
  `ts` timestamp NULL DEFAULT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin COMMENT='文件信息表';
```